package cn.com.qmth.examcloud.core.oe.admin.dao.entity;

import cn.com.qmth.examcloud.core.oe.admin.dao.enums.ExamRecordStatus;
import cn.com.qmth.examcloud.core.oe.admin.dao.enums.ExamType;
import cn.com.qmth.examcloud.core.oe.admin.dao.enums.IsSuccess;
import cn.com.qmth.examcloud.web.jpa.JpaEntity;
import org.hibernate.annotations.DynamicInsert;

import javax.persistence.*;
import java.util.Date;

/**
 * @author chenken
 * @date 2018年8月13日 上午11:41:34
 * @company QMTH
 * @description 考试记录数据表, 与ec_oe_exam_record一对一关系
 */
@Entity
@Table(name = "ec_oe_exam_record_data", indexes = {
        @Index(name = "IDX_E_O_E_R_D_001", columnList = "examStudentId"),
        @Index(name = "IDX_E_O_E_R_D_002", columnList = "studentCode"),
        @Index(name = "IDX_E_O_E_R_D_003", columnList = "studentId,examType"),
        @Index(name = "IDX_E_O_E_R_D_004", columnList = "examId"),
        @Index(name = "IDX_E_O_E_R_D_005", columnList = "courseId"),
        @Index(name = "IDX_E_O_E_R_D_006", columnList = "examRecordStatus"),
})
@DynamicInsert
public class ExamRecordDataEntity extends JpaEntity {
    /**
     *
     */
    private static final long serialVersionUID = -242327915801750970L;
    /**
     * 主键
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;
    /**
     * 考试ID
     */
    private Long examId;
    /**
     * 考试类型
     */
    @Column(length = 20)
    @Enumerated(EnumType.STRING)
    private ExamType examType;
    /**
     * 考生ID
     */
    private Long examStudentId;
    /**
     * 学生ID
     */
    private Long studentId;
    /**
     * 学号
     */
    @Column(length = 50)
    private String studentCode;
    /**
     * 学生姓名
     */
    @Column(length = 20)
    private String studentName;
    /**
     * 身份证号
     */
    @Column(length = 20)
    private String identityNumber;
    /**
     * 课程ID
     */
    private Long courseId;

    private String courseLevel;
    /**
     * 学习中心ID
     */
    private Long orgId;
    /**
     * 顶级机构ID
     */
    private Long rootOrgId;
    /**
     * 基础试卷ID
     */
    private String basePaperId;

    /**
     * 试卷类型
     */
    private String paperType;
    /**
     * 试卷结构 ID
     */
    private String paperStructId;
    /**
     * 采集人
     */
    @Column(length = 255)
    private String infoCollector;

    /**
     * 考试作答记录id
     */
    private String examRecordQuestionsId;
    /**
     * 考试记录状态(考试中,考试结束,考试过期,考试作废)
     */
    @Enumerated(EnumType.STRING)
    private ExamRecordStatus examRecordStatus;
    /**
     * 考试开始时间
     */
    private Date startTime;
    /**
     * 考试结束时间
     */
    private Date endTime;
    /**
     * 考试被清理时间
     */
    private Date cleanTime;
    /**
     * 是否异常数据
     */
    private Boolean isWarn;
    /**
     * 是否被审核过
     */
    private Boolean isAudit;
    /**
     * 是否违纪
     */
    @Column(name = "is_illegality")
    private Boolean isIllegality;

    /**
     * 考试时长
     */
    private Long usedExamTime;
    /**
     * 第几次考试
     */
    private Integer examOrder;
    /**
     * 是否为重考
     */
    @Column(name = "is_reexamine")
    private Boolean isReexamine;
    /**
     * 是否断点续考
     */
    @Column(name = "is_continued")
    private Boolean isContinued;
    /**
     * 是否是全客观题卷  1:是   0:否
     */
    private Boolean isAllObjectivePaper;
    /**
     * 断点续考次数
     */
    private Integer continuedCount;
    /**
     * 是否达到最大断点限制
     */
    private Boolean isExceed;
    /**
     * 抓拍比对成功次数
     */
    private Integer faceSuccessCount;
    /**
     * 抓拍比对失败次数
     */
    private Integer faceFailedCount;
    /**
     * 抓拍存在陌生人的次数
     */
    private Integer faceStrangerCount;
    /**
     * 抓拍比对总次数
     */
    private Integer faceTotalCount;
    /**
     * 抓拍比对成功比率
     */
    private Double faceSuccessPercent;
    /**
     * @see cn.com.qmth.examcloud.core.oe.admin.dao.enums.IsSuccess
     * 活体检测结果
     */
    @Column(length = 20)
    @Enumerated(EnumType.STRING)
    private IsSuccess faceVerifyResult;

    /**
     * 百度人脸活体检测通过率
     */
    private Double baiduFaceLivenessSuccessPercent;
    /**
     * 人脸五官坐标比对值
     */
    private Double faceLandmarkVal;

    /**
     * 总分
     */
    private Double totalScore;

    /**
     * 客观题得分总分
     */
    private Double objectiveScore;

    /**
     * 客观题答对的比率
     * (客观题答对的题数/客观题总题数)*100  取2位小数
     */
    private Double objectiveAccuracy;

    /**
     * 主观题得分总分
     */
    private Double subjectiveScore;

    /**
     * 答题正确率
     */
    private Double succPercent;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public ExamType getExamType() {
        return examType;
    }

    public void setExamType(ExamType examType) {
        this.examType = examType;
    }

    public Long getExamStudentId() {
        return examStudentId;
    }

    public void setExamStudentId(Long examStudentId) {
        this.examStudentId = examStudentId;
    }

    public Long getStudentId() {
        return studentId;
    }

    public void setStudentId(Long studentId) {
        this.studentId = studentId;
    }

    public String getStudentCode() {
        return studentCode;
    }

    public void setStudentCode(String studentCode) {
        this.studentCode = studentCode;
    }

    public String getStudentName() {
        return studentName;
    }

    public void setStudentName(String studentName) {
        this.studentName = studentName;
    }

    public String getIdentityNumber() {
        return identityNumber;
    }

    public void setIdentityNumber(String identityNumber) {
        this.identityNumber = identityNumber;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getRootOrgId() {
        return rootOrgId;
    }

    public void setRootOrgId(Long rootOrgId) {
        this.rootOrgId = rootOrgId;
    }

    public String getBasePaperId() {
        return basePaperId;
    }

    public void setBasePaperId(String basePaperId) {
        this.basePaperId = basePaperId;
    }

    public String getPaperStructId() {
        return paperStructId;
    }

    public void setPaperStructId(String paperStructId) {
        this.paperStructId = paperStructId;
    }

    public String getPaperType() {
        return paperType;
    }

    public void setPaperType(String paperType) {
        this.paperType = paperType;
    }

    public String getCourseLevel() {
        return courseLevel;
    }

    public void setCourseLevel(String courseLevel) {
        this.courseLevel = courseLevel;
    }

    public String getInfoCollector() {
        return infoCollector;
    }

    public void setInfoCollector(String infoCollector) {
        this.infoCollector = infoCollector;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Date getCleanTime() {
        return cleanTime;
    }

    public void setCleanTime(Date cleanTime) {
        this.cleanTime = cleanTime;
    }

    public Boolean getIsWarn() {
        return isWarn;
    }

    public void setIsWarn(Boolean isWarn) {
        this.isWarn = isWarn;
    }

    public Boolean getIsAudit() {
        return isAudit;
    }

    public void setIsAudit(Boolean isAudit) {
        this.isAudit = isAudit;
    }

    public Boolean getIsIllegality() {
        return isIllegality;
    }

    /**
     * 设置是否违纪
     *
     * @param isIllegality
     */
    public void setIsIllegality(Boolean isIllegality) {
        this.isIllegality = isIllegality;
    }

    public ExamRecordStatus getExamRecordStatus() {
        return examRecordStatus;
    }

    public void setExamRecordStatus(ExamRecordStatus examRecordStatus) {
        this.examRecordStatus = examRecordStatus;
    }

    public Long getUsedExamTime() {
        return usedExamTime;
    }

    public void setUsedExamTime(Long usedExamTime) {
        this.usedExamTime = usedExamTime;
    }

    public Integer getExamOrder() {
        return examOrder;
    }

    public void setExamOrder(Integer examOrder) {
        this.examOrder = examOrder;
    }

    public Boolean getIsReexamine() {
        return isReexamine;
    }

    public void setIsReexamine(Boolean isReexamine) {
        this.isReexamine = isReexamine;
    }

    public Boolean getIsContinued() {
        return isContinued;
    }

    public void setIsContinued(Boolean isContinued) {
        this.isContinued = isContinued;
    }

    public Integer getContinuedCount() {
        return continuedCount;
    }

    public void setContinuedCount(Integer continuedCount) {
        this.continuedCount = continuedCount;
    }

    public Integer getFaceSuccessCount() {
        return faceSuccessCount;
    }

    public void setFaceSuccessCount(Integer faceSuccessCount) {
        this.faceSuccessCount = faceSuccessCount;
    }

    public Integer getFaceFailedCount() {
        return faceFailedCount;
    }

    public void setFaceFailedCount(Integer faceFailedCount) {
        this.faceFailedCount = faceFailedCount;
    }

    public Integer getFaceStrangerCount() {
        return faceStrangerCount;
    }

    public void setFaceStrangerCount(Integer faceStrangerCount) {
        this.faceStrangerCount = faceStrangerCount;
    }

    public Integer getFaceTotalCount() {
        return faceTotalCount;
    }

    public void setFaceTotalCount(Integer faceTotalCount) {
        this.faceTotalCount = faceTotalCount;
    }

    public Double getFaceSuccessPercent() {
        return faceSuccessPercent;
    }

    public void setFaceSuccessPercent(Double faceSuccessPercent) {
        this.faceSuccessPercent = faceSuccessPercent;
    }

    public IsSuccess getFaceVerifyResult() {
        return faceVerifyResult;
    }

    public void setFaceVerifyResult(IsSuccess faceVerifyResult) {
        this.faceVerifyResult = faceVerifyResult;
    }

    public Double getFaceLandmarkVal() {
        return faceLandmarkVal;
    }

    public void setFaceLandmarkVal(Double faceLandmarkVal) {
        this.faceLandmarkVal = faceLandmarkVal;
    }

    public Boolean getIsAllObjectivePaper() {
        return isAllObjectivePaper;
    }

    public void setIsAllObjectivePaper(Boolean isAllObjectivePaper) {
        this.isAllObjectivePaper = isAllObjectivePaper;
    }

    public Double getBaiduFaceLivenessSuccessPercent() {
        return baiduFaceLivenessSuccessPercent;
    }

    public void setBaiduFaceLivenessSuccessPercent(
            Double baiduFaceLivenessSuccessPercent) {
        this.baiduFaceLivenessSuccessPercent = baiduFaceLivenessSuccessPercent;
    }

    public Boolean getIsExceed() {
        return isExceed;
    }

    public void setIsExceed(Boolean isExceed) {
        this.isExceed = isExceed;
    }

    public String getExamRecordQuestionsId() {
        return examRecordQuestionsId;
    }

    public void setExamRecordQuestionsId(String examRecordQuestionsId) {
        this.examRecordQuestionsId = examRecordQuestionsId;
    }

    public Double getTotalScore() {
        return totalScore;
    }

    public void setTotalScore(Double totalScore) {
        this.totalScore = totalScore;
    }

    public Double getObjectiveScore() {
        return objectiveScore;
    }

    public void setObjectiveScore(Double objectiveScore) {
        this.objectiveScore = objectiveScore;
    }

    public Double getObjectiveAccuracy() {
        return objectiveAccuracy;
    }

    public void setObjectiveAccuracy(Double objectiveAccuracy) {
        this.objectiveAccuracy = objectiveAccuracy;
    }

    public Double getSubjectiveScore() {
        return subjectiveScore;
    }

    public void setSubjectiveScore(Double subjectiveScore) {
        this.subjectiveScore = subjectiveScore;
    }

    public Double getSuccPercent() {
        return succPercent;
    }

    public void setSuccPercent(Double succPercent) {
        this.succPercent = succPercent;
    }
}